@@ -4,10 +4,11 @@ import logging
 import pprint
 import time
 from signal import SIGINT, signal
-from threading import Thread
 
 import soco
 
+from os import environ as env
+
 from .action_processor import list_actions, process_action
 from .speakers import Speakers
 from .utils import (
@@ -19,7 +20,9 @@ from .utils import (
     docs,
     error_and_exit,
     get_speaker,
+    logo,
     seconds_until,
+    set_interactive,
     set_speaker_list,
     sig_handler,
     version,
@@ -29,6 +32,10 @@ from .utils import (
 pp = pprint.PrettyPrinter(width=100)
 
 
+# Speaker name environment variable
+env_spkr_name = "SPKR"
+
+
 def main():
     # Handle SIGINT
     signal(SIGINT, sig_handler)
@@ -70,6 +77,19 @@ def main():
         default=False,
         help="Print the list of available actions",
     )
+    parser.add_argument(
+        "--interactive",
+        "-i",
+        action="store_true",
+        default=False,
+        help="Enter interactive mode",
+    )
+    parser.add_argument(
+        "--no-env",
+        action="store_true",
+        default=False,
+        help="Ignore the 'SPKR' environment variable, if set",
+    )
     # The rest of the optional args are common
     configure_common_args(parser)
 
@@ -84,11 +104,15 @@ def main():
         docs()
         exit(0)
 
+    if args.logo:
+        logo()
+        exit(0)
+
     if args.actions or args.commands:
         list_actions()
         exit(0)
 
-    if len(args.parameters) == 0:
+    if len(args.parameters) == 0 and not args.interactive:
         print("No parameters. Use 'sonos --help' for usage information")
         exit(0)
 
@@ -111,6 +135,23 @@ def main():
             speaker_list.save()
         set_speaker_list(speaker_list)
 
+    # Is $SPKR set in the environment?
+    env_speaker = None
+    if not args.no_env:
+        logging.info("Ignoring 'SPKR' environment variable")
+        env_speaker = env.get(env_spkr_name)
+
+    if args.interactive:
+        speaker_name = None
+        if len(args.parameters):
+            speaker_name = args.parameters[0]
+        interactive_loop(
+            speaker_name,
+            use_local_speaker_list=use_local_speaker_list,
+            no_env=args.no_env,
+        )
+        exit(0)
+
     # Break up the command line into command sequences, observing the separator.
     command_line_separator = ":"
     sequence = []  # A single command sequence
@@ -308,6 +349,16 @@ def main():
                     )
                 continue
 
+            # Use the speaker name from the environment?
+            if env_speaker:
+                logging.info(
+                    "Getting speaker name '{}' from the $SPKR environment variable".format(
+                        env_speaker
+                    )
+                )
+                sequence.insert(0, env_speaker)
+                speaker_name = env_speaker
+
             # General action processing
             if len(sequence) < 2:
                 error_and_exit(
@@ -353,5 +404,42 @@ def main():
     exit(0)
 
 
+def interactive_loop(speaker_name, use_local_speaker_list=False, no_env=False):
+
+    # Is the speaker name set on the command line?
+    # Is the speaker name set in the environment?
+    speaker = None
+    if not speaker_name and not no_env:
+        speaker_name = env.get(env_spkr_name)
+    if speaker_name:
+        speaker = get_speaker(speaker_name, use_local_speaker_list)
+        if not speaker:
+            error_and_exit("Speaker '{}' not found".format(speaker_name))
+
+    print("Entering SoCo-CLI interactive mode")
+    set_interactive()
+    while True:
+        logging.info("Entering interactive mode")
+        command = input("Enter sonos action (0 to exit) > ")
+        if command == "0":
+            logging.info("Exiting interactive mode")
+            return True
+
+        # Command processing
+        try:
+            args = command.split()
+            if not speaker_name:
+                speaker = get_speaker(args.pop(0), use_local_speaker_list)
+                if not speaker:
+                    print("Error: Speaker not found")
+                    continue
+            action = args.pop(0)
+            response = process_action(speaker, action, args, use_local_speaker_list)
+            if not response:
+                print("Error: Action '{}'".format(action))
+        except:
+            print("Error: Invalid command")
+
+
 if __name__ == "__main__":
     main()
